==> sagua_0.2.0-1.tar.gz: sagua-0.2.0/src/fileentry.cc <==
// Sagua is music player.
// Copyright (C) 2004 HG, Rhee <ez8tank@krpost.net>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

/// @file fileentry.cc
/// @brief Class for filename entry and browse button source file.

#include <libintl.h>

#include <gtkmm/stock.h>

#include "../include/fileentry.h"

void FileEntry::OnBtnBrowse()
{
    Gtk::FileChooserDialog fileChooserDlg(parentWnd_, gettext("Choose background image file"));
    fileChooserDlg.set_local_only(true);
    fileChooserDlg.set_select_multiple(false);
    fileChooserDlg.add_button(Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
    fileChooserDlg.add_button(Gtk::Stock::OK, Gtk::RESPONSE_OK);

    int result = fileChooserDlg.run();
    fileChooserDlg.hide();

    switch(result) {
	case(Gtk::RESPONSE_OK) :
	    {
		Glib::ustring selectedFilename = fileChooserDlg.get_filename();
		filenameEntry_.set_text(Glib::filename_to_utf8(selectedFilename));

		break;
	    }

	case(Gtk::RESPONSE_CANCEL):
	default:
	    break; 
    }
}

void FileEntry::on_size_request(Gtk::Requisition* requisition)
{
    *requisition = Gtk::Requisition();

    Gtk::Requisition req;
    std::vector<Gtk::Widget*> children = get_children();
    (*children.begin())->size_request(req);
    int height = req.height;
    int width = 0;

    for(std::vector<Gtk::Widget*>::iterator eachWidget = children.begin();
	    eachWidget != children.end();
	    ++eachWidget) {

	(*eachWidget)->size_request(req);

	if(req.height > height)
	    height = req.height;

	width += req.width;
	width += 12;	
    }

    width -= 12;

    requisition->height = height;
    requisition->width = width;
}

void FileEntry::on_size_allocate(Gtk::Allocation& allocation)
{
    set_allocation(allocation);

    Gtk::Allocation childAllocation;
    Gtk::Requisition req, req2;
    std::vector<Gtk::Widget*> children = get_children();
    (*children.begin())->size_request(req);
    size_request(req2);
    int height = req.height;
    int x = allocation.get_x();
    int y = allocation.get_y();
    y += (req2.height - height) / 2;
    y += 6;

    for(std::vector<Gtk::Widget*>::iterator eachWidget = children.begin();
	    eachWidget != children.end();
	    ++eachWidget) {

	(*eachWidget)->size_request(req);

	childAllocation.set_x(x);
	childAllocation.set_y(y);
	childAllocation.set_width(req.width);
	childAllocation.set_height(height);
	(*eachWidget)->size_allocate(childAllocation);    

	x += req.width;
	x += 12;	
    }

}

==> sagua_0.2.3-1.tar.gz: sagua-0.2.3/src/fileentry.cc <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mod: nil; c-basic-offset: 4 -*- */
// Sagua is music player.
// Copyright (C) 2004 HG, Rhee <ez8tank@krpost.net>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

/// @file fileentry.cc
/// @brief Class for filename entry and browse button source file.

#include <libintl.h>

#include <gtkmm/stock.h>

#include "../include/fileentry.h"

void FileEntry::OnBtnBrowse()
{
    Gtk::FileChooserDialog fileChooserDlg(parentWnd_, gettext("Choose background image file"));
    fileChooserDlg.set_local_only(true);
    fileChooserDlg.set_select_multiple(false);
    fileChooserDlg.add_button(Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
    fileChooserDlg.add_button(Gtk::Stock::OK, Gtk::RESPONSE_OK);

    int result = fileChooserDlg.run();
    fileChooserDlg.hide();

    switch(result) {
    case(Gtk::RESPONSE_OK) :
        {

            filenameEntry_.set_text(Glib::filename_to_utf8(fileChooserDlg.get_filename()));

            break;
        }

    case(Gtk::RESPONSE_CANCEL):
    default:
        break; 
    }
}

void FileEntry::on_size_request(Gtk::Requisition* requisition)
{
    *requisition = Gtk::Requisition();

    std::vector<Gtk::Widget*> children(get_children());
    Gtk::Requisition req;
    (*children.begin())->size_request(req);
    int height = req.height;
    int width = 0;

    for(std::vector<Gtk::Widget*>::iterator eachWidget(children.begin());
        eachWidget != children.end();
        ++eachWidget) {

	(*eachWidget)->size_request(req);

	if(req.height > height)
	    height = req.height;

	width += req.width;
	width += borderWidth_;	
    }

    // Remove last border
    width -= borderWidth_;

    requisition->height = height;
    requisition->width = width;
}

void FileEntry::on_size_allocate(Gtk::Allocation& allocation)
{
    set_allocation(allocation);

    std::vector<Gtk::Widget*> children(get_children());
    Gtk::Requisition req, req2;
    (*children.begin())->size_request(req);
    size_request(req2);

    int x = allocation.get_x();
    const int height = req.height;
    const int y = allocation.get_y() + (req2.height - height + borderWidth_) / 2;

    Gtk::Allocation childAllocation;
    for(std::vector<Gtk::Widget*>::iterator eachWidget(children.begin());
        eachWidget != children.end();
        ++eachWidget) {

	(*eachWidget)->size_request(req);

	childAllocation.set_x(x);
	childAllocation.set_y(y);
	childAllocation.set_width(req.width);
	childAllocation.set_height(height);
	(*eachWidget)->size_allocate(childAllocation);    

	x += req.width;
	x += borderWidth_;	
    }
}
